<?php
/**
 * @package RSDirectory!
 * @copyright (C) 2013-2018 www.rsjoomla.com
 * @license GPL, http://www.gnu.org/licenses/gpl-3.0.html
 */

// Ensure this file is being included by a parent file.
if ( ! ( defined( '_VALID_CB' ) || defined( '_JEXEC' ) || defined( '_VALID_MOS' ) ) )
{
	die('Direct Access to this location is not allowed.');
}

class getRSDirectoryTab extends cbTabHandler
{
	/**
	* Constructor.
	*
	* @access public
	*/
	public function __construct()
	{
		$this->cbTabHandler();
	}
		
	/**
	* Generates the HTML to display the user profile tab
	*
	* @access public
	*  
	* @param moscomprofilerTab $tab The tab database entry
	* @param moscomprofilerUser $user The user being displayed
	* @param int $ui 1 for front-end, 2 for back-end
	* 
	* @return mixed Either string HTML for tab content, or false if ErrorMSG generated
	*/
	public function getDisplayTab($tab, $user, $ui)
	{
		if ( !file_exists(JPATH_ADMINISTRATOR . '/components/com_rsdirectory/helpers/rsdirectory.php') )
			return;
			
		require_once JPATH_ADMINISTRATOR . '/components/com_rsdirectory/helpers/rsdirectory.php';
			
		$params	= $this->params;
		$limit = $params->get('limit', 5);
		$ordering = $params->get('ordering', 'ASC');
		$itemid = $params->get('itemid', '');
			
		// Load language and style.
		JFactory::getLanguage()->load('com_rsdirectory');
		JHtml::_('stylesheet', 'components/com_comprofiler/plugin/user/plug_rsdirectory/style.css', array('relative' => false, 'version' => 'auto'));
			
		$entries = $this->_getEntries($user->id, $limit, $ordering);
			
		ob_start();
			
		echo '<div class="rsdir-entries-container">';	
			
		if ( empty($entries) )
		{
			echo '<div>' . JText::_('COM_RSDIRECTORY_CB_NO_ENTRIES') . '</div>';
		}
		else
		{
			$rsconfig = RSDirectoryConfig::getInstance();
			$width = $rsconfig->get('small_thumbnail_width');
			$height = $rsconfig->get('small_thumbnail_height');
				
			$show_thumbs = $params->get('show_thumbs', 1);
			$show_info = $params->get('show_info', 1);
				
			$target = $params->get('target', 1);
			$opener = $target ? '' : ' target="_blank"';
				
			$form = (object)array(
				'listing_row_show_author' => 0,
				'listing_row_show_publishing_time' => 1,
				'listing_row_show_category' => 1,
				'listing_row_show_category_hierarchy' => 1
			);
				
			echo '<h3>' . JText::_('COM_RSDIRECTORY_CB_MY_ENTRIES') . '</h3>';
				
			echo '<ul class="rsdir-entries">';
				
			foreach ($entries as $entry)
			{
				$route = "index.php?option=com_rsdirectory&view=entry&id=" . RSDirectoryHelper::sef($entry->id, $entry->title);
				$route .= $itemid ? "&Itemid=$itemid" : '';
				$url = JRoute::_($route);
				$title = RSDirectoryHelper::escapeHTML($entry->title);
				unset($src);
					
				?>
					
				<li>
					<?php if ($show_thumbs) { ?>
					<a<?php echo $opener; ?> href="<?php echo $url; ?>" title="<?php echo $title; ?>">
					<?php
						
					if ( !empty($entry->form->fields) )
					{
						$images_field = RSDirectoryHelper::findFormField('images', $entry->form->fields);
							
						if ( !empty($images_field->files) )
						{
							$src = RSDirectoryHelper::getImageURL($images_field->files[0]->hash, 'small');
								
							?>
								
							<img class="rsdir-avatar" src="<?php echo $src; ?>" width="<?php echo $width; ?>" height="<?php echo $height; ?>" alt="<?php echo $title; ?>" />
								
							<?php
						}
					}
						
					if ( empty($src) )
					{
						?>
							
						<i class="rsdir-no-image cAvatar"></i>	
							
						<?php
					}
						
					?>
					</a>
					<?php } ?>
						
					<?php if ($show_thumbs) { ?>
					<div class="rsdir-content">
					<?php } ?>
						<h4>
							<a<?php echo $opener; ?> href="<?php echo $url; ?>" title="<?php echo $title; ?>">
								<?php echo $title; ?>
							</a>
						</h4>
							
						<?php echo $show_info ? RSDirectoryHelper::getEntryMeta($entry, $form) : ''; ?>
					<?php if ($show_thumbs) { ?>
					</div>
					<?php } ?>
				</li>
					
				<?php
			}
				
			echo '</ul>';
		}
			
		echo '</div>';
			
		$html = ob_get_contents();
		ob_end_clean();
			
		return $html;
	}
		
	/**
	 * Method to get a list of entries.
	 *
	 * @access public
	 *
	 * @param int $user_id
	 * @param int $limit
	 * @param string $order
	 *
	 * @return array
	 */
	function _getEntries($user_id, $limit, $order)
	{
		// Get DBO.
		$db = JFactory::getDbo();
		
		$select = array(
			$db->qn('e') . '.*',
			$db->qn('u.name', 'author'),
			$db->qn('c.title', 'category_title'),
		);
			
		$query = $db->getQuery(true)
			   ->select($select)
			   ->from( $db->qn('#__rsdirectory_entries', 'e') )
			   ->innerJoin( $db->qn('#__categories', 'c') . ' ON ' . $db->qn('e.category_id') . ' = ' . $db->qn('c.id') )
			   ->innerJoin( $db->qn('#__users', 'u') . ' ON ' . $db->qn('e.user_id') . ' = ' . $db->qn('u.id') )
			   ->where( $db->qn('e.user_id') . ' = ' . $db->q($user_id) )
			   ->where( $db->qn('e.published') . ' = ' . $db->q(1) )
			   ->where( $db->qn('u.block') . ' = ' . $db->q(0) )
			   ->where( '(' . $db->qn('e.expiry_time') . ' = ' . $db->q('0000-00-00 00:00:00') . ' OR ' . $db->qn('e.expiry_time') . ' > ' . $db->q( JFactory::getDate()->toSql() ) . ')' )
			   ->order( $db->qn('e.published_time') . ' ' . $db->escape($order) );
				
		$db->setQuery($query, 0, $limit);
			
		$entries = $db->loadObjectList();
			
		if ($entries)
		{
			return RSDirectoryHelper::getEntriesData($entries);
		}
			
		return $entries;
	}
}